@@ -3,15 +3,19 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menu.c,v 1.1.1.1 2003/12/04 00:10:12 dom Exp $
- *   $Date: 2003/12/04 00:10:12 $
+ *   $Id: menu.c,v 1.7 2003/12/04 21:08:01 dom Exp $
+ *   $Date: 2003/12/04 21:08:01 $
  *
  *
  *   Constructs a menu and all such things
  *
  */
 
-#include "menuapp.h"
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#include "app.h"
 
 
 /* Number of rows we can display on the menu */
@@ -63,7 +67,7 @@ static int        menu_keys(void *ptr, int code);
 
 menu_t *new_menu(dongle_t *dongle,render_t *render, app_t *app,menu_t *parent, void *param, int flags)
 {
-    menu_t       *menu = malloc(sizeof(*menu));
+    menu_t       *menu = (menu_t *)malloc(sizeof(*menu));
 
     menu->dongle = dongle;
     menu->render = render;
@@ -151,7 +155,7 @@ void menu_add_option(menu_t *menu, char *name, int (callback_func)(menu_t *menu,
 {
     int     i = menu->numoptions++;
 
-    menu->options = realloc(menu->options,menu->numoptions * sizeof(option_t));
+    menu->options = (option_t *)realloc(menu->options,menu->numoptions * sizeof(option_t));
 
     menu->options[i].name = strdup(name);
     menu->options[i].callback_func = callback_func;
@@ -165,7 +169,7 @@ void menu_add(menu_t *menu, char *name, int (*callback_func)(menu_t *menu,void *
 {
     int     i = menu->numoptions++;
 
-    menu->options = realloc(menu->options,menu->numoptions * sizeof(option_t));
+    menu->options = (option_t *)realloc(menu->options,menu->numoptions * sizeof(option_t));
 
     menu->options[i].name = strdup(name);
     menu->options[i].callback_func = callback_func;
@@ -206,7 +210,6 @@ void menu_display(menu_t *menu)
         ? menu->top_offset + MENU_ROWS(menu) : menu->numoptions;
     for ( row = 2, i = menu->top_offset; i < last; i++, row++ ) {
         if ( menu->options[i].type == MENU_INT ) {
-            printf("option %d val %d\n",i,*((int *)menu->options[i].value_ptr));
             extra = menu->options[i].options[*((int *)menu->options[i].value_ptr)];
         } else {
             extra = "";
@@ -272,7 +275,7 @@ void menu_display(menu_t *menu)
 
 static int menu_keys(void *ptr, int code)
 {
-    menu_t    *menu = ptr;
+    menu_t    *menu = (menu_t *)ptr;
     int        pos;
     int      (*func)(menu_t *,void *param, int sel);
     int      (*cfunc)(menu_t *,void *param, int key,int sel);
@@ -281,9 +284,7 @@ static int menu_keys(void *ptr, int code)
     int      streamtype = 0;
 
 
-    if ( menu->dongle->stream ) {
-        streamtype = stream_get_type(menu->dongle->stream);
-    }
+    streamtype = dongle_get_type(menu->dongle);
 
 
     /* If we're in streaming mpeg mode, then we'd like to change channels
@@ -291,7 +292,7 @@ static int menu_keys(void *ptr, int code)
     */
     if ( streamtype == ( MEDIA_MPEG | MEDIA_SOCKET ) ) {
         switch ( code ) {
-        case kChanUp:
+        case keyChanUp:
             if ( menu->current_selection < menu->numoptions - 1 ) {
                 menu->current_selection++;
                 if ( menu->top_offset + MENU_ROWS(menu) <= menu->current_selection ) {
@@ -310,7 +311,7 @@ static int menu_keys(void *ptr, int code)
                 parent->child = NULL;        
             }  
             break;
-        case kChanDn:
+        case keyChanDn:
             if ( menu->current_selection > 0 ) {
                 menu->current_selection--;
                 if ( menu->top_offset > menu->current_selection ) {
@@ -337,7 +338,7 @@ static int menu_keys(void *ptr, int code)
 
 
     switch ( code ) {
-    case kChanUp:
+    case keyChanUp:
         if ( streamtype != MEDIA_MPEG ) {
             if ( menu->current_selection > 0 ) {
                 menu->current_selection--;
@@ -354,7 +355,7 @@ static int menu_keys(void *ptr, int code)
             menu_display(menu);
         }
         break;
-    case kChanDn:
+    case keyChanDn:
         if ( streamtype != MEDIA_MPEG ) {
             if ( menu->current_selection < menu->numoptions - 1 ) {
                 menu->current_selection++;
@@ -380,11 +381,11 @@ static int menu_keys(void *ptr, int code)
             }
         }
         break;
-    case kVolUp:
+    case keyVolUp:
         option = &menu->options[menu->current_selection];
         if ( option->type == MENU_INT ) {
             menu_t *parent = menu->parent;
-            num = option->value_ptr;           
+            num = (unsigned int *)option->value_ptr;           
             *num = ( *num + 1 ) % option->num_options;
             func = menu->options[menu->current_selection].callback_func;
             if ( func && func(menu,menu->param,-1) == 0 ) {
@@ -395,11 +396,11 @@ static int menu_keys(void *ptr, int code)
   
         }
         break;
-    case kVolDn:
+    case keyVolDn:
         option = &menu->options[menu->current_selection];
         if ( option->type == MENU_INT ) {
             menu_t *parent = menu->parent;
-            num = option->value_ptr;
+            num = (unsigned int *)option->value_ptr;
             if ( *num == 0 ) {
                 *num = option->num_options - 1;
             } else {
@@ -414,7 +415,7 @@ static int menu_keys(void *ptr, int code)
 
         }
         break;
-    case kBack:
+    case keyBack:
         if ( menu->parent ) {
             menu_t *parent = menu->parent;
             delete_menu(menu);
@@ -422,26 +423,26 @@ static int menu_keys(void *ptr, int code)
             menu_display(parent);
         }
         break;
-    case kSkip:        /* Go down a page */
-	if ( menu->current_selection + MENU_ROWS(menu) > ( menu->numoptions - MENU_ROWS(menu) ) ) {
-	    menu->current_selection = menu->top_offset = menu->numoptions - MENU_ROWS(menu);
-	    if ( menu->current_selection < 0 ) {
-		menu->current_selection = menu->top_offset = 0;
-	    }
-	} else {
-	    menu->current_selection = menu->top_offset =  menu->current_selection + MENU_ROWS(menu);
-	}
-	menu_display(menu);
-	break;
-    case kReplay:       /* Go up a page */
-	if ( menu->current_selection - MENU_ROWS(menu) < 0 ) {
-	    menu->current_selection = menu->top_offset = 0;
-	} else {
-	    menu->current_selection = menu->top_offset =  menu->current_selection - MENU_ROWS(menu);
-	}
-	menu_display(menu);
-	break;
-    case kGo:
+    case keySkip:        /* Go down a page */
+        if ( menu->current_selection + MENU_ROWS(menu) > ( menu->numoptions - MENU_ROWS(menu) ) ) {
+            menu->current_selection = menu->top_offset = menu->numoptions - MENU_ROWS(menu);
+            if ( menu->current_selection < 0 ) {
+                menu->current_selection = menu->top_offset = 0;
+            }
+        } else {
+            menu->current_selection = menu->top_offset =  menu->current_selection + MENU_ROWS(menu);
+        }
+        menu_display(menu);
+        break;
+    case keyReplay:       /* Go up a page */
+        if ( menu->current_selection - MENU_ROWS(menu) < 0 ) {
+            menu->current_selection = menu->top_offset = 0;
+        } else {
+            menu->current_selection = menu->top_offset =  menu->current_selection - MENU_ROWS(menu);
+        }
+        menu_display(menu);
+        break;
+    case keyGo:
         while ( menu->parent ) {
             menu_t *parent = menu->parent;
             delete_menu(menu);
@@ -450,7 +451,7 @@ static int menu_keys(void *ptr, int code)
         }
         menu_display(menu);
         break;
-    case kOk:
+    case keyOk:
         if ( menu->options != NULL ) {
             menu_t  *parent;
             func = menu->options[menu->current_selection].callback_func;
@@ -462,9 +463,9 @@ static int menu_keys(void *ptr, int code)
             }        
         }
         break;
-    case k1 ... k9:
+    case key1 ... key9:
         if ( menu->flags & MENU_NUMBERS ) {
-            pos = code - k1;
+            pos = code - key1;
             if ( pos < menu->numoptions && menu->options ) {
                 func = menu->options[pos].callback_func;
                 if ( func && func(menu,menu->param,pos) == 0 ) {
@@ -473,10 +474,10 @@ static int menu_keys(void *ptr, int code)
             }
         }
         break;
-    case kRed ... kBlue:
+    case keyRed ... keyBlue:
         cfunc = menu->colour_func;        
         if ( cfunc && cfunc(menu,menu->param,code,menu->current_selection) == 0 ) {
-	    menu_t *parent;
+            menu_t *parent;
             parent = menu->parent;
             delete_menu(menu);
             parent->child = NULL;        
@@ -545,7 +546,9 @@ void menu_set_colour_actions(menu_t *menu,
     menu->colour_func = func;
 }
 
-
+#ifdef __cplusplus
+}
+#endif
 
 
  
