@@ -3,13 +3,19 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menuapp.c,v 1.1.1.1 2003/12/04 00:10:13 dom Exp $
- *   $Date: 2003/12/04 00:10:13 $
+ *   $Id: menuapp.c,v 1.6 2003/12/04 19:43:33 dom Exp $
+ *   $Date: 2003/12/04 19:43:33 $
  *
  *
  *   Implements the application
  */
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+#include "app.h"
 #include "menuapp.h"
 #include "libini.h"
 
@@ -51,10 +57,17 @@ typedef struct {
     char     *url;
 } channel_t;
 
+#ifdef VDR_PLUGIN
+static char         *c_livetv_file = "/video/livetv";
+static char         *c_liveradio_file = "/video/liveradio";
+static char         *c_mp3_dir     = "/home/mp3";
+static char         *c_mpeg_dir    = "/video";
+#else
 static char         *c_livetv_file = NULL;
 static char         *c_liveradio_file = NULL;
 static char         *c_mp3_dir     = ".";
 static char         *c_mpeg_dir    = ".";
+#endif
 
 static int           livetv_num    = 0;
 static channel_t    *livetv        = NULL;
@@ -107,6 +120,7 @@ static void          next_media_push(menuapp_t *menuapp, char *url);
 
 static int           read_channel_file(char *filename, int *num, channel_t **list, time_t *update_time);
 
+#ifndef VDR_PLUGIN
 void menuapp_config()
 {
     iniparse_add("media:livetv",OPT_STR,&c_livetv_file);
@@ -114,6 +128,7 @@ void menuapp_config()
     iniparse_add("media:mp3",OPT_STR,&c_mp3_dir);
     iniparse_add("media:mpeg",OPT_STR,&c_mpeg_dir);
 }
+#endif
 
 
 void menuapp_init()
@@ -135,7 +150,7 @@ void menuapp_init()
 
 menuapp_t *new_menuapp(dongle_t *dongle, render_t *render, app_t *app)
 {
-    menuapp_t      *menuapp = malloc(sizeof(*menuapp));
+    menuapp_t      *menuapp = (menuapp_t *)malloc(sizeof(*menuapp));
 
     menuapp->render = render;
     menuapp->app    = app;
@@ -174,7 +189,7 @@ void delete_menuapp(menuapp_t *menuapp)
 
 static int menuapp_main(menu_t *menu,void *imenuapp, int sel)
 {   
-    menuapp_t   *menuapp = imenuapp;
+    menuapp_t   *menuapp = (menuapp_t *)imenuapp;
 
     menuapp->menu = new_menu(menuapp->dongle,menuapp->render,menuapp->app,NULL,menuapp,MENU_NUMBERS);
     menu_set_title(menuapp->menu,"MediaMVP");
@@ -196,7 +211,7 @@ static int menuapp_main(menu_t *menu,void *imenuapp, int sel)
 
 static int menuapp_live_tv(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t     *menuapp = imenuapp;
+    menuapp_t     *menuapp = (menuapp_t *)imenuapp;
     channel_t *chan;
     menu_t    *child;
     int        i;
@@ -217,10 +232,10 @@ static int menuapp_live_tv(menu_t *menu,void *imenuapp, int sel)
 
 static int process_livetv(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t     *menuapp = imenuapp;
+    menuapp_t     *menuapp = (menuapp_t *)imenuapp;
 
     channel_t *chan = &livetv[sel];
-    gui_send_play(menuapp->dongle->gui,chan->url);
+    dongle_send_play(menuapp->dongle,chan->url);
     app_register_keys(menuapp->app,REGISTER_MEDIA,livetv_keys,menuapp);
     app_register_ack(menuapp->app,REGISTER_MEDIA,livetv_ack,menuapp);
     return 1;
@@ -228,13 +243,13 @@ static int process_livetv(menu_t *menu,void *imenuapp, int sel)
 
 static int livetv_ack(int acktype, void *param, unsigned char *buf, int len)
 {
-    menuapp_t     *menuapp = param;
+    menuapp_t     *menuapp = (menuapp_t *)param;
 
     switch ( acktype ) {
     case RDC_PLAY:
-        if ( (stream_get_type(menuapp->dongle->stream) & MEDIA_MASK) == MEDIA_MPEG ) {
-            gui_send_message(menuapp->dongle->gui,&rfb_media_menu);
-            gui_send_message(menuapp->dongle->gui,&rfb_display_off);
+        if ( (dongle_get_type(menuapp->dongle) & MEDIA_MASK) == MEDIA_MPEG ) {
+            dongle_send_message(menuapp->dongle,&rfb_media_menu);
+            dongle_send_message(menuapp->dongle,&rfb_display_off);
         }
         break;
     case RDC_STOP:             
@@ -243,11 +258,11 @@ static int livetv_ack(int acktype, void *param, unsigned char *buf, int len)
         if ( menuapp->num_next_media ) {
             next_media_pop(menuapp);           
             menuapp->paused = FALSE;
-            gui_send_play(menuapp->dongle->gui,menuapp->current_media);
+            dongle_send_play(menuapp->dongle,menuapp->current_media);
         } else {
-            if ( ( stream_get_lasttype(menuapp->dongle->stream) & MEDIA_MASK ) == MEDIA_MPEG ) {
-                gui_send_message(menuapp->dongle->gui,&rfb_media_menu);
-                gui_send_message(menuapp->dongle->gui,&rfb_display_on);
+            if ( ( dongle_get_lasttype(menuapp->dongle) & MEDIA_MASK ) == MEDIA_MPEG ) {
+                dongle_send_message(menuapp->dongle,&rfb_media_menu);
+                dongle_send_message(menuapp->dongle,&rfb_display_on);
             }
             if ( menuapp->current_media ) {
                 free(menuapp->current_media);
@@ -271,22 +286,22 @@ static int livetv_ack(int acktype, void *param, unsigned char *buf, int len)
 
 static int livetv_keys(void *ptr, int code)
 {
-    menuapp_t    *menuapp = ptr;
+    menuapp_t    *menuapp = (menuapp_t *)ptr;
 
     switch ( code ) {
-    case kMenu:
-    case kStop:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_stop);
+    case keyMenu:
+    case keyStop:
+        dongle_send_message(menuapp->dongle,&rfb_media_stop);
         menu_display(menuapp->menu);
         break;
-    case kVolUp:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_volup);
+    case keyVolUp:
+        dongle_send_message(menuapp->dongle,&rfb_media_volup);
         break;
-    case kVolDn:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_voldown);
+    case keyVolDn:
+        dongle_send_message(menuapp->dongle,&rfb_media_voldown);
         break;
-    case kMute:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_mute);
+    case keyMute:
+        dongle_send_message(menuapp->dongle,&rfb_media_mute);
         break;
     default:
         return 0;  /* Do more keys */
@@ -303,7 +318,7 @@ static int livetv_keys(void *ptr, int code)
 
 static int menuapp_live_radio(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t     *menuapp = imenuapp;
+    menuapp_t     *menuapp = (menuapp_t *)imenuapp;
     channel_t *chan;
     menu_t    *child;
     int        i;
@@ -322,18 +337,17 @@ static int menuapp_live_radio(menu_t *menu,void *imenuapp, int sel)
 
 static int process_liveradio(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t     *menuapp = imenuapp;
+    menuapp_t     *menuapp = (menuapp_t *)imenuapp;
     channel_t *chan = &liveradio[sel];
 
-    printf("Sending media do request %s\n",chan->url);
     if ( menuapp->current_media == NULL ) {        
         menuapp->current_media = strdup(chan->url);
         menuapp->paused = FALSE;
-        gui_send_play(menuapp->dongle->gui,chan->url);
+        dongle_send_play(menuapp->dongle,chan->url);
     } else {
         next_media_clear(menuapp);
         next_media_push(menuapp,chan->url);       
-        gui_send_message(menuapp->dongle->gui,&rfb_media_stop);
+        dongle_send_message(menuapp->dongle,&rfb_media_stop);
     }
     app_register_keys(menuapp->app,REGISTER_MEDIA,liveradio_keys,menuapp);
     app_register_ack(menuapp->app,REGISTER_MEDIA,liveradio_ack,menuapp);
@@ -343,22 +357,22 @@ static int process_liveradio(menu_t *menu,void *imenuapp, int sel)
 
 static int liveradio_keys(void *ptr, int code)
 {
-    menuapp_t     *menuapp = ptr;
+    menuapp_t     *menuapp = (menuapp_t *)ptr;
 
     switch ( code ) { 
-    case kStop:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_stop);
+    case keyStop:
+        dongle_send_message(menuapp->dongle,&rfb_media_stop);
         next_media_clear(menuapp);
         menu_display(menuapp->menu);
         break;
-    case kVolUp:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_volup);
+    case keyVolUp:
+        dongle_send_message(menuapp->dongle,&rfb_media_volup);
         break;
-    case kVolDn:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_voldown);
+    case keyVolDn:
+        dongle_send_message(menuapp->dongle,&rfb_media_voldown);
         break;
-    case kMute:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_mute);
+    case keyMute:
+        dongle_send_message(menuapp->dongle,&rfb_media_mute);
         break;
     default:
         return 0;      /* Carry on processing menu keys */
@@ -368,14 +382,14 @@ static int liveradio_keys(void *ptr, int code)
 
 static int liveradio_ack(int acktype, void *param, unsigned char *buf, int len)
 {
-    menuapp_t     *menuapp = param;
+    menuapp_t     *menuapp = (menuapp_t *)param;
 
     switch ( acktype ) {
     case RDC_STOP:     /* The client has sent a stop message */  
         if ( menuapp->num_next_media ) {
             next_media_pop(menuapp);
             menuapp->paused = FALSE;
-            gui_send_play(menuapp->dongle->gui,menuapp->current_media);
+            dongle_send_play(menuapp->dongle,menuapp->current_media);
         } else {
             /* Remove registered handlers */
             if ( menuapp->current_media ) {
@@ -400,7 +414,7 @@ static int liveradio_ack(int acktype, void *param, unsigned char *buf, int len)
  */
 static int menuapp_mpeg(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t      *menuapp = imenuapp;
+    menuapp_t      *menuapp = (menuapp_t *)imenuapp;
     dirlist_t  *dirlist;
     menu_t     *child;
     char        buf[256];
@@ -434,7 +448,7 @@ static int menuapp_mpeg(menu_t *menu,void *imenuapp, int sel)
 static int process_mpeg(menu_t *menu,void *imenuapp, int sel)
 {
     char         buf[FILENAME_MAX+1];
-    dirlist_t    *dirlist = imenuapp;
+    dirlist_t    *dirlist = (dirlist_t *)imenuapp;
     dirlist_t    *dirlist2;
     filelist_t   *entry;
     menu_t       *child;
@@ -475,12 +489,12 @@ static int process_mpeg(menu_t *menu,void *imenuapp, int sel)
             dirlist->menuapp->current_media = strdup(buf);
             dirlist->menuapp->paused = FALSE;
 //            next_media_push(dirlist->menuapp,buf);
-            gui_send_play(dirlist->menuapp->dongle->gui,buf);
+            dongle_send_play(dirlist->menuapp->dongle,buf);
         } else {
             next_media_clear(dirlist->menuapp);
             next_media_push(dirlist->menuapp,buf);           
             dirlist->menuapp->paused = FALSE;
-            gui_send_message(dirlist->menuapp->dongle->gui,&rfb_media_stop);    
+            dongle_send_message(dirlist->menuapp->dongle,&rfb_media_stop);    
         }
         app_register_keys(dirlist->menuapp->app,REGISTER_MEDIA,mpeg_keys,dirlist->menuapp);
         app_register_ack(dirlist->menuapp->app,REGISTER_MEDIA,mpeg_ack,dirlist->menuapp);
@@ -492,9 +506,10 @@ static int process_mpeg(menu_t *menu,void *imenuapp, int sel)
 static int mpeg_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 {
     switch ( key ) {
-    case kRed:
+    case keyRed:
         return 0;   
     default:
+        break;
     }
 
     return 1;     /* Carry on displaying this menu */
@@ -502,47 +517,47 @@ static int mpeg_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 
 static int mpeg_keys(void *ptr, int code)
 {
-    menuapp_t     *menuapp = ptr;
+    menuapp_t     *menuapp = (menuapp_t *)ptr;
 
     switch ( code ) { 
-    case kStop:
+    case keyStop:
         next_media_clear(menuapp);
-        gui_send_message(menuapp->dongle->gui,&rfb_media_stop);
+        dongle_send_message(menuapp->dongle,&rfb_media_stop);
         menu_display(menuapp->menu);
         break;
-    case kPlay:
-        gui_send_play(menuapp->dongle->gui,menuapp->current_media);
+    case keyPlay:
+        dongle_send_play(menuapp->dongle,menuapp->current_media);
         menuapp->paused = FALSE;
         break;
-    case kPause:
+    case keyPause:
         if ( menuapp->paused ) {
             menuapp->paused = FALSE;
-            gui_send_play(menuapp->dongle->gui,menuapp->current_media);
+            dongle_send_play(menuapp->dongle,menuapp->current_media);
         } else {
             menuapp->paused = TRUE;
-            gui_send_message(menuapp->dongle->gui,&rfb_media_pause);
+            dongle_send_message(menuapp->dongle,&rfb_media_pause);
         }
         break;
-    case kVolUp:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_volup);
+    case keyVolUp:
+        dongle_send_message(menuapp->dongle,&rfb_media_volup);
         break;
-    case kVolDn:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_voldown);
+    case keyVolDn:
+        dongle_send_message(menuapp->dongle,&rfb_media_voldown);
         break;
-    case kMute:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_mute);
+    case keyMute:
+        dongle_send_message(menuapp->dongle,&rfb_media_mute);
         break;
 #if 0
         /* Forward/reverse don't work...erk! */
-    case kFastFwd:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_forward);
+    case keyFastFwd:
+        dongle_send_message(menuapp->dongle,&rfb_media_forward);
         break;
-    case kFastRew:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_rewind);
+    case keyFastRew:
+        dongle_send_message(menuapp->dongle,&rfb_media_rewind);
         break;
 #endif
-    case kSkip:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_stop);
+    case keySkip:
+        dongle_send_message(menuapp->dongle,&rfb_media_stop);
         break;
     default:
         return 0;      /* Carry on processing menu keys */
@@ -553,24 +568,24 @@ static int mpeg_keys(void *ptr, int code)
 
 static int mpeg_ack(int acktype, void *param, unsigned char *buf, int len)
 {
-    menuapp_t         *menuapp = param;
+    menuapp_t         *menuapp = (menuapp_t *)param;
 
     switch ( acktype ) {
     case RDC_PLAY:
-        if ( (stream_get_type(menuapp->dongle->stream) & MEDIA_MASK) == MEDIA_MPEG ) {
-            gui_send_message(menuapp->dongle->gui,&rfb_media_menu);
-            gui_send_message(menuapp->dongle->gui,&rfb_display_off);
+        if ( (dongle_get_type(menuapp->dongle) & MEDIA_MASK) == MEDIA_MPEG ) {
+            dongle_send_message(menuapp->dongle,&rfb_media_menu);
+            dongle_send_message(menuapp->dongle,&rfb_display_off);
         }
         break;
     case RDC_STOP:     /* The client has sent a stop message */ 
         if ( menuapp->num_next_media ) {
             next_media_pop(menuapp);
             menuapp->paused = FALSE;
-            gui_send_play(menuapp->dongle->gui,menuapp->current_media);          
+            dongle_send_play(menuapp->dongle,menuapp->current_media);          
         } else {
-          if ( ( stream_get_lasttype(menuapp->dongle->stream) & MEDIA_MASK ) == MEDIA_MPEG ) {
-                gui_send_message(menuapp->dongle->gui,&rfb_media_menu);
-                gui_send_message(menuapp->dongle->gui,&rfb_display_on);
+          if ( ( dongle_get_lasttype(menuapp->dongle) & MEDIA_MASK ) == MEDIA_MPEG ) {
+                dongle_send_message(menuapp->dongle,&rfb_media_menu);
+                dongle_send_message(menuapp->dongle,&rfb_display_on);
             }
             if ( menuapp->current_media ) {
                 free(menuapp->current_media);
@@ -584,7 +599,7 @@ static int mpeg_ack(int acktype, void *param, unsigned char *buf, int len)
         break;
     case RDC_FORWARD:
     case RDC_REWIND:
-        gui_send_play(menuapp->dongle->gui,menuapp->current_media);
+        dongle_send_play(menuapp->dongle,menuapp->current_media);
         break;
     default:
         return 0;    /* Kick it up a level */
@@ -601,7 +616,7 @@ static int mpeg_ack(int acktype, void *param, unsigned char *buf, int len)
  */
 static int menuapp_music(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t      *menuapp = imenuapp;
+    menuapp_t      *menuapp = (menuapp_t *)imenuapp;
     dirlist_t  *dirlist;
     menu_t     *child;
     char        buf[256];
@@ -636,7 +651,7 @@ static int menuapp_music(menu_t *menu,void *imenuapp, int sel)
 static int process_music(menu_t *menu,void *imenuapp, int sel)
 {
     char         buf[FILENAME_MAX+1];
-    dirlist_t    *dirlist = imenuapp;
+    dirlist_t    *dirlist = (dirlist_t *)imenuapp;
     dirlist_t    *dirlist2;
     filelist_t   *entry;
     menu_t       *child;
@@ -676,12 +691,12 @@ static int process_music(menu_t *menu,void *imenuapp, int sel)
         if ( dirlist->menuapp->current_media == NULL ) {        
             dirlist->menuapp->current_media = strdup(buf);
             dirlist->menuapp->paused = FALSE;
-            gui_send_play(dirlist->menuapp->dongle->gui,buf);
+            dongle_send_play(dirlist->menuapp->dongle,buf);
         } else {
             next_media_clear(dirlist->menuapp);
             next_media_push(dirlist->menuapp,buf);           
             dirlist->menuapp->paused = FALSE;
-            gui_send_message(dirlist->menuapp->dongle->gui,&rfb_media_stop);    
+            dongle_send_message(dirlist->menuapp->dongle,&rfb_media_stop);    
         }
         app_register_keys(dirlist->menuapp->app,REGISTER_MEDIA,music_keys,dirlist->menuapp);
         app_register_ack(dirlist->menuapp->app,REGISTER_MEDIA,music_ack,dirlist->menuapp);
@@ -693,14 +708,14 @@ static int process_music(menu_t *menu,void *imenuapp, int sel)
 static int music_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 {
     char           buf[FILENAME_MAX+1];
-    dirlist_t     *dir = imenuapp;
+    dirlist_t     *dir = (dirlist_t *)imenuapp;
     int            i;
     char           play = TRUE;
 
     switch ( key ) {
-    case kRed:
+    case keyRed:
         return 0;
-    case kGreen:       /* Add all contents of the directory */
+    case keyGreen:       /* Add all contents of the directory */
         if ( dir->menuapp->current_media ) {
             play = FALSE;
         }
@@ -715,15 +730,16 @@ static int music_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
         if ( dir->menuapp->num_next_media ) {
             if ( play ) {
                 next_media_pop(dir->menuapp);
-                gui_send_play(dir->menuapp->dongle->gui,dir->menuapp->current_media);
+                dongle_send_play(dir->menuapp->dongle,dir->menuapp->current_media);
                 app_register_keys(dir->menuapp->app,REGISTER_MEDIA,music_keys,dir->menuapp);
                 app_register_ack(dir->menuapp->app,REGISTER_MEDIA,music_ack,dir->menuapp);
             } else {
-                gui_send_message(dir->menuapp->dongle->gui,&rfb_media_stop);
+                dongle_send_message(dir->menuapp->dongle,&rfb_media_stop);
             }
         }
         break;
     default:
+        break;
     }
 
     return 1;     /* Carry on displaying this menu */
@@ -731,44 +747,44 @@ static int music_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 
 static int music_keys(void *ptr, int code)
 {
-    menuapp_t     *menuapp = ptr;
+    menuapp_t     *menuapp = (menuapp_t *)ptr;
 
     switch ( code ) { 
-    case kStop:
+    case keyStop:
         next_media_clear(menuapp);
-        gui_send_message(menuapp->dongle->gui,&rfb_media_stop);
+        dongle_send_message(menuapp->dongle,&rfb_media_stop);
         menu_display(menuapp->menu);
         break;
-    case kPlay:
-        gui_send_play(menuapp->dongle->gui,menuapp->current_media);
+    case keyPlay:
+        dongle_send_play(menuapp->dongle,menuapp->current_media);
         menuapp->paused = FALSE;
         break;
-    case kPause:
+    case keyPause:
         if ( menuapp->paused ) {
             menuapp->paused = FALSE;
-            gui_send_play(menuapp->dongle->gui,menuapp->current_media);
+            dongle_send_play(menuapp->dongle,menuapp->current_media);
         } else {
             menuapp->paused = TRUE;
-            gui_send_message(menuapp->dongle->gui,&rfb_media_pause);
+            dongle_send_message(menuapp->dongle,&rfb_media_pause);
         }
         break;
-    case kVolUp:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_volup);
+    case keyVolUp:
+        dongle_send_message(menuapp->dongle,&rfb_media_volup);
         break;
-    case kVolDn:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_voldown);
+    case keyVolDn:
+        dongle_send_message(menuapp->dongle,&rfb_media_voldown);
         break;
-    case kMute:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_mute);
+    case keyMute:
+        dongle_send_message(menuapp->dongle,&rfb_media_mute);
         break;
-    case kFastFwd:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_forward);
+    case keyFastFwd:
+        dongle_send_message(menuapp->dongle,&rfb_media_forward);
         break;
-    case kFastRew:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_rewind);
+    case keyFastRew:
+        dongle_send_message(menuapp->dongle,&rfb_media_rewind);
         break;
-    case kSkip:
-        gui_send_message(menuapp->dongle->gui,&rfb_media_stop);
+    case keySkip:
+        dongle_send_message(menuapp->dongle,&rfb_media_stop);
         break;
     default:
         return 0;      /* Carry on processing menu keys */
@@ -778,14 +794,14 @@ static int music_keys(void *ptr, int code)
 
 static int music_ack(int acktype, void *param, unsigned char *buf, int len)
 {
-    menuapp_t         *menuapp = param;
+    menuapp_t         *menuapp = (menuapp_t *)param;
 
     switch ( acktype ) {
     case RDC_STOP:     /* The client has sent a stop message */  
         if ( menuapp->num_next_media ) {
             next_media_pop(menuapp);
             menuapp->paused = FALSE;
-            gui_send_play(menuapp->dongle->gui,menuapp->current_media);          
+            dongle_send_play(menuapp->dongle,menuapp->current_media);          
         } else {
             /* Remove registered handlers */
             if ( menuapp->current_media ) {
@@ -799,7 +815,7 @@ static int music_ack(int acktype, void *param, unsigned char *buf, int len)
         break;
     case RDC_FORWARD:
     case RDC_REWIND:
-        gui_send_play(menuapp->dongle->gui,menuapp->current_media);
+        dongle_send_play(menuapp->dongle,menuapp->current_media);
         break;
     default:
         return 0;    /* Kick it up a level */
@@ -818,7 +834,7 @@ static int music_ack(int acktype, void *param, unsigned char *buf, int len)
  ***********************/
 static int menuapp_settings(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t           *menuapp = imenuapp;
+    menuapp_t       *menuapp = (menuapp_t *)imenuapp;
     menu_t          *child;
     static char     *tvmode[]  = { "NTSC", "PAL" };
     static char     *flicker[] = { "None", "Low", "Medium", "High" };
@@ -857,7 +873,7 @@ static int menuapp_settings(menu_t *menu,void *imenuapp, int sel)
 
 static int process_settings(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t   *menuapp = imenuapp;
+    menuapp_t   *menuapp = (menuapp_t *)imenuapp;
     /* Some rules preened from the configuration.html:
 
     1). For NTSC unit -- in response to GUI query, video output value 
@@ -881,13 +897,13 @@ static int process_settings(menu_t *menu,void *imenuapp, int sel)
         if ( menuapp->dongle->tvmode == 0 ) {
             menuapp->dongle->videooutput = 3;
         }
-        gui_send_settings(menuapp->dongle->gui,RDC_SETTINGS_TEST);
+        dongle_send_settings(menuapp->dongle,RDC_SETTINGS_TEST);
         return 1;  /* Carry on displaying current menu */
     case 4:
-        gui_send_settings(menuapp->dongle->gui,RDC_SETTINGS_CANCEL);
+        dongle_send_settings(menuapp->dongle,RDC_SETTINGS_CANCEL);
         return 0;
     case 5:
-        gui_send_settings(menuapp->dongle->gui,RDC_SETTINGS_SAVE);
+        dongle_send_settings(menuapp->dongle,RDC_SETTINGS_SAVE);
         return 0;
     default:
         return 0;   /* Carry on displaying */
@@ -898,7 +914,7 @@ static int process_settings(menu_t *menu,void *imenuapp, int sel)
 
 static dirlist_t    *new_dirlist(menuapp_t *menuapp)
 {
-    dirlist_t   *dir = malloc(sizeof(*dir));
+    dirlist_t   *dir = (dirlist_t *)malloc(sizeof(*dir));
 
     dir->filelist_num = 0;
     dir->filelist = NULL;
@@ -909,7 +925,7 @@ static dirlist_t    *new_dirlist(menuapp_t *menuapp)
 
 static void          delete_dirlist(void *idir)
 {
-    dirlist_t *dir = idir;
+    dirlist_t *dir = (dirlist_t *)idir;
     int        i;
 
     for ( i = 0; i < dir->filelist_num; i++ ) {
@@ -960,7 +976,7 @@ static filelist_t *directory_scan(char *path, int *scanned)
         }
 
         i = num++;
-        list = realloc(list, num * sizeof(filelist_t));
+        list = (filelist_t *)realloc(list, num * sizeof(filelist_t));
 
         list[i].name = strdup(dirent->d_name);
         list[i].flags = flags;
@@ -1046,7 +1062,7 @@ static int read_channel_file(char *filename, int *num, channel_t **list,
 
             i = channum++;
 
-            chan = realloc(chan,channum * sizeof(channel_t));
+            chan = (channel_t *)realloc(chan,channum * sizeof(channel_t));
             chan[i].name = strdup(buf);
             chan[i].url = strdup(ptr);            
         }
@@ -1096,11 +1112,14 @@ static void next_media_push(menuapp_t *menuapp, char *url)
 {
     int       i = menuapp->num_next_media++;
 
-    menuapp->next_media = realloc(menuapp->next_media,menuapp->num_next_media * sizeof(char *));
+    menuapp->next_media = (char **)realloc(menuapp->next_media,menuapp->num_next_media * sizeof(char *));
     menuapp->next_media[i] = strdup(url);
 }
 
 
+#ifdef __cplusplus
+}
+#endif
 
 /*
  * Local Variables:
